@@ -113,7 +113,6 @@ class FluxAgentRegistrar:
         self.sub_agents: list = []
         self.runners: list = []
         self.app = web.Application()
-        self.log = log
         self._ready_to_serve = False
 
     @property
@@ -138,6 +137,7 @@ class FluxAgentRegistrar:
         self.app.router.add_post("/update", self.handle_update)
 
         if self.enable_fileserver:
+            log.info("Enabling LAN fileserver...")
             self.app.router.add_get("/file/{file_name}", self.download_file)
 
         self.runners.append(runner)
